==> node-typescript_2.1.5.orig.tar.gz: TypeScript-2.1.5/tests/baselines/reference/contextuallyTypedClassExpressionMethodDeclaration01.js <==
//// [contextuallyTypedClassExpressionMethodDeclaration01.ts]

interface A {
    numProp: number;
}

interface B  {
    strProp: string;
}

interface Foo {
    method1(arg: A): void;
    method2(arg: B): void;
}

function getFoo1(): Foo {
    return class {
        static method1(arg) {
            arg.numProp = 10;
        }
        static method2(arg) {
            arg.strProp = "hello";
        }
    }
}

function getFoo2(): Foo {
    return class {
        static method1 = (arg) => {
            arg.numProp = 10;
        }
        static method2 = (arg) => {
            arg.strProp = "hello";
        }
    }
}

function getFoo3(): Foo {
    return class {
        static method1 = function (arg) {
            arg.numProp = 10;
        }
        static method2 = function (arg) {
            arg.strProp = "hello";
        }
    }
}

//// [contextuallyTypedClassExpressionMethodDeclaration01.js]
function getFoo1() {
    return (function () {
        function class_1() {
        }
        class_1.method1 = function (arg) {
            arg.numProp = 10;
        };
        class_1.method2 = function (arg) {
            arg.strProp = "hello";
        };
        return class_1;
    }());
}
function getFoo2() {
    return _a = (function () {
            function class_2() {
            }
            return class_2;
        }()),
        _a.method1 = function (arg) {
            arg.numProp = 10;
        },
        _a.method2 = function (arg) {
            arg.strProp = "hello";
        },
        _a;
    var _a;
}
function getFoo3() {
    return _a = (function () {
            function class_3() {
            }
            return class_3;
        }()),
        _a.method1 = function (arg) {
            arg.numProp = 10;
        },
        _a.method2 = function (arg) {
            arg.strProp = "hello";
        },
        _a;
    var _a;
}

==> node-typescript_2.7.2.orig.tar.gz: TypeScript-2.7.2/tests/baselines/reference/contextuallyTypedClassExpressionMethodDeclaration01.js <==
//// [contextuallyTypedClassExpressionMethodDeclaration01.ts]
interface A {
    numProp: number;
}

interface B  {
    strProp: string;
}

interface Foo {
    method1(arg: A): void;
    method2(arg: B): void;
}

function getFoo1(): Foo {
    return class {
        static method1(arg) {
            arg.numProp = 10;
        }
        static method2(arg) {
            arg.strProp = "hello";
        }
    }
}

function getFoo2(): Foo {
    return class {
        static method1 = (arg) => {
            arg.numProp = 10;
        }
        static method2 = (arg) => {
            arg.strProp = "hello";
        }
    }
}

function getFoo3(): Foo {
    return class {
        static method1 = function (arg) {
            arg.numProp = 10;
        }
        static method2 = function (arg) {
            arg.strProp = "hello";
        }
    }
}

//// [contextuallyTypedClassExpressionMethodDeclaration01.js]
function getFoo1() {
    return /** @class */ (function () {
        function class_1() {
        }
        class_1.method1 = function (arg) {
            arg.numProp = 10;
        };
        class_1.method2 = function (arg) {
            arg.strProp = "hello";
        };
        return class_1;
    }());
}
function getFoo2() {
    return _a = /** @class */ (function () {
            function class_2() {
            }
            return class_2;
        }()),
        _a.method1 = function (arg) {
            arg.numProp = 10;
        },
        _a.method2 = function (arg) {
            arg.strProp = "hello";
        },
        _a;
    var _a;
}
function getFoo3() {
    return _a = /** @class */ (function () {
            function class_3() {
            }
            return class_3;
        }()),
        _a.method1 = function (arg) {
            arg.numProp = 10;
        },
        _a.method2 = function (arg) {
            arg.strProp = "hello";
        },
        _a;
    var _a;
}
